Author: laukpe
Date: Tue Nov 25 14:27:43 2008
New Revision: 1118
Added:
trunk/tools/libdoc/test/new_style_no_init.py (contents, props changed)
Modified:
trunk/tools/libdoc/test/no_arg_init.py
Log:
new test, cleanup
Added: trunk/tools/libdoc/test/new_style_no_init.py
==============================================================================
--- (empty file)
+++ trunk/tools/libdoc/test/new_style_no_init.py Tue Nov 25 14:27:43 2008
@@ -0,0 +1,6 @@
+class new_style_no_init(object):
+
+ """No __init__ on this one."""
+
+ def kw(self):
+ """The only lonely keyword."""
Modified: trunk/tools/libdoc/test/no_arg_init.py
==============================================================================
--- trunk/tools/libdoc/test/no_arg_init.py (original)
+++ trunk/tools/libdoc/test/no_arg_init.py Tue Nov 25 14:27:43 2008
@@ -1,19 +1,20 @@
class no_arg_init:
def __init__(self):
- """This doc not shown because there are no arguments"""
- import os
+ """This doc not shown because there are no arguments."""
def keyword(self):
- """A keyword
+ """A keyword.
- See `get hello` for details"""
- pass
+ See `get hello` for details and *never* run this keyword.
+ """
+ 1/0
- def get_hello(self):
- """Get the intialization variables
+ def get_hello(self, arg):
+ """Returns 'Hello `arg`!'.
- See `initialization` for explanation of arguments
- and `introduction` for introduction"""
- return self.arg1, self.arg2
+ See `initialization` for explanation of arguments and
`introduction`
+ for introduction. Neither of them really exist, though.
+ """
+ return 'Hello %s' % arg